---
title: Конфигурация зоны DNS
template: docs
taxonomy:
    category: docs
routes:
  default: '/dns_config'
  aliases:
    - '/dns'
---

DNS (система доменных имен) - это система, которая преобразует удобочитаемые адреса
(доменные имена) в адреса, понятные машине (IP). Чтобы ваш сервер был
легко доступен людям, а некоторые службы, такие как почта, работали
должным образом, необходимо настроить DNS.

Если вы используете [автоматический домен](/dns_nohost_me), предоставляемый проектом YunoHost, настройка должна
выполняться автоматически. Если вы используете свое собственное доменное имя (например, купленное через
регистратора), вам следует вручную настроить свой домен в
интерфейсе вашего регистратора.

## Рекомендуемая конфигурация DNS

ПРИМЕЧАНИЕ: В примерах здесь используется заполнитель `your.domain.tld`, вы должны заменить его своим реальным доменом, например `www.yunohost.org`.

YunoHost предоставляет рекомендуемую конфигурацию DNS, доступную через:
- веб-администратор, Домены > `your.domain.tld` > DNS;
- или в командной строке: `yunohost domain dns-conf your.domain.tld`

Для конкретных нужд или конкретных настроек, и если вы знаете, что делаете, вы
можете захотеть или быть вынуждены изменить их или добавить дополнительные (например, для обработки
поддоменов).

Рекомендуемая конфигурация обычно выглядит следующим образом:

```bash
#
# Базовые ipv4/ipv6 записи
#
@ 3600 IN A 111.222.33.44
* 3600 IN A 111.222.33.44

# (Если ваш сервер поддерживает IPv6, есть несколько записей AAAA)
@ 3600 IN AAAA 2222:444:8888:3333:bbbb:5555:3333:1111
* 3600 IN AAAA 2222:444:8888:3333:bbbb:5555:3333:1111

#
# XMPP
#
_xmpp-client._tcp 3600 IN SRV 0 5 5222 your.domain.tld.
_xmpp-server._tcp 3600 IN SRV 0 5 5269 your.domain.tld.
muc 3600 IN CNAME @
pubsub 3600 IN CNAME @
vjud 3600 IN CNAME @
xmpp-upload 3600 IN CNAME @

#
# Почтовые (MX, SPF, DKIM and DMARC)
#
@ 3600 IN MX 10 your.domain.tld.
@ 3600 IN TXT "v=spf1 a mx -all"
mail._domainkey 3600 IN TXT "v=DKIM1; k=rsa; p=someHuuuuuuugeKey"
_dmarc 3600 IN TXT "v=DMARC1; p=none"
```

Хотя, возможно, было бы легче понять это, если бы оно отображалось следующим образом:


| Тип    | Название                   | Значение                                                 |
| :-----: | :--------------------: | :--------------------------------------------------:  |
|  **A**  |   **@**                |  `111.222.333.444` (ваш IPv4)                        |
|    A    |   *                    |  `111.222.333.444` (ваш IPv4)                        |
|  AAAA   |   @                    |  `2222:444:8888:3333:bbbb:5555:3333:1111` (ваш IPv6) |
|  AAAA   |   *                    |  `2222:444:8888:3333:bbbb:5555:3333:1111` (ваш IPv6) |
| **SRV** | **_xmpp-client._tcp**  |  `0 5 5222 your.domain.tld.`                          |
| **SRV** | **_xmpp-server._tcp**  |  `0 5 5269 your.domain.tld.`                          |
|  CNAME  |   muc                  |  `@`                                                  |
|  CNAME  |   pubsub               |  `@`                                                  |
|  CNAME  |   vjud                 |  `@`                                                  |
|  CNAME  |   xmpp-upload          |  `@`                                                  |
| **MX**  | **@**                  |  `your.domain.tld.`     (с приоритетом: 10)            |
|   TXT   |   @                    |  `"v=spf1 a mx -all"`               |
|   TXT   |  mail._domainkey       |  `"v=DKIM1; k=rsa; p=someHuuuuuuugeKey"`              |
|   TXT   |  _dmarc                |  `"v=DMARC1; p=none"`                                 |

#### Несколько замечаний по поводу этой таблицы

- Не все эти строки абсолютно необходимы. Для минимальной настройки вам понадобятся только записи, выделенные жирным шрифтом.
- Точка в конце `ваш.домен.tld.` важна ;);
- `@` соответствует `your.domain.tld`, и, например, `muc` соответствует `muc.your.domain.tld`;
- Это примерные значения! Смотрите сгенерированный вами conf для получения фактических значений, которые вы должны использовать;
- Мы рекомендуем использовать [TTL](https://en.wikipedia.org/wiki/Time_to_live#DNS_records ) 3600 (1 час). Но вы можете использовать что-то еще, если знаете, что делаете;
- Не размещайте запись IPv6, если вы не уверены, что IPv6 действительно работает на вашем сервере! У вас могут возникнуть проблемы с Let's Encrypt, если это не так.
- Если вы используете Namecheap поставщика домена, записи SRV DNS форматируются как **Сервис**: _xmpp-client **Протокол**: _tcp **Приоритет**: 0 **Вес**: 5 **Порт**: 5222 **Цель**: your.domain.tld

### Обратный DNS

Если ваш интернет-провайдер или VPS-провайдер позволяет вам определить [обратный
поиск DNS](https://ru.wikipedia.org/wiki/%D0%9E%D0%B1%D1%80%D0%B0%D1%82%D0%BD%D1%8B%D0%B9_%D0%BF%D1%80%D0%BE%D1%81%D0%BC%D0%BE%D1%82%D1%80_DNS) для ваших общедоступных IPv4
и/или IPv6-адресов вы должны настроить его. Это предотвратит пометку вас
антиспам-фильтрами как нежелательные письма.

**Примечание: обратная настройка DNS выполняется у вашего интернет-провайдера или VPS-провайдера. Это *не* обрабатывается регистратором вашего домена.**

Если ваш общедоступный IPv4-адрес `111.222.333.444`, а ваш DNS
-домен - `domain.tld`, вы должны получить следующий ответ при использовании
командной строки `nslookup`:

```shell
$ nslookup 111.222.333.444
444.333.222.111.in-addr.arpa    name = domain.tld.
```

Система диагностики, доступная в webadmin, выполняет эту проверку автоматически (в разделе Электронная почта).

### Динамический IP-адрес

Если ваш глобальный IP-адрес постоянно меняется, следуйте этому [руководству](/dns_dynamic_ip).
